@@ -26,15 +26,33 @@ namespace SparkleLib {
 
     public class SparkleConfig : XmlDocument {
 
-        public static SparkleConfig DefaultConfig = new SparkleConfig (
-            SparklePaths.SparkleConfigPath, "config.xml");
+        public static string ConfigPath = Path.Combine (
+            Environment.GetFolderPath (Environment.SpecialFolder.ApplicationData),
+            "sparkleshare");
 
-        public string Path;
+        public static SparkleConfig DefaultConfig = new SparkleConfig (
+            ConfigPath, "config.xml");
+
+
+        public string FullPath;
+
+        public string HomePath = Environment.GetFolderPath (Environment.SpecialFolder.Personal);
+        public string TmpPath;
+
+        public string FoldersPath {
+            get {
+                if (GetConfigOption ("folders_path") != null)
+                    return GetConfigOption ("folders_path");
+                else
+                    return Path.Combine (HomePath, "SparkleShare");
+            }
+        }
 
 
         public SparkleConfig (string config_path, string config_file_name)
         {
-            Path = System.IO.Path.Combine (config_path, config_file_name);
+            FullPath = System.IO.Path.Combine (config_path, config_file_name);
+            TmpPath  = Path.Combine (FoldersPath, ".tmp");
 
             if (!Directory.Exists (config_path)) {
                 Directory.CreateDirectory (config_path);
@@ -47,10 +65,10 @@ namespace SparkleLib {
                 SparkleHelpers.DebugInfo ("Config", "Created \"" + icons_path + "\"");
             }
 
-            if (!File.Exists (Path))
+            if (!File.Exists (FullPath))
                 CreateInitialConfig ();
 
-            Load (Path);
+            Load (FullPath);
         }
 
 
@@ -74,7 +92,7 @@ namespace SparkleLib {
             if (string.IsNullOrEmpty (user_name))
                 user_name = "Unknown";
 
-            TextWriter writer = new StreamWriter (Path);
+            TextWriter writer = new StreamWriter (FullPath);
             string n          = Environment.NewLine;
 
             writer.Write ("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>" + n +
@@ -86,36 +104,31 @@ namespace SparkleLib {
                           "</sparkleshare>");
             writer.Close ();
 
-            SparkleHelpers.DebugInfo ("Config", "Created \"" + Path + "\"");
+            SparkleHelpers.DebugInfo ("Config", "Created \"" + FullPath + "\"");
         }
 
 
-        public string UserName {
+        public SparkleUser User {
             get {
-                XmlNode node = SelectSingleNode ("/sparkleshare/user/name/text()");
-                return node.Value;
+                XmlNode name_node = SelectSingleNode ("/sparkleshare/user/name/text()");
+                string name  = name_node.Value;
+
+                XmlNode email_node = SelectSingleNode ("/sparkleshare/user/email/text()");
+                string email = email_node.Value;
+
+                return new SparkleUser (name, email);
             }
 
             set {
-                XmlNode node = SelectSingleNode ("/sparkleshare/user/name/text()");
-                node.InnerText = value;
+                SparkleUser user = (SparkleUser) value;
 
-                Save ();
-            }
-        }
+                XmlNode name_node = SelectSingleNode ("/sparkleshare/user/name/text()");
+                name_node.InnerText = user.Name;
 
+                XmlNode email_node = SelectSingleNode ("/sparkleshare/user/email/text()");
+                email_node.InnerText = user.Email;
 
-        public string UserEmail {
-            get {
-                XmlNode node = SelectSingleNode ("/sparkleshare/user/email/text()");
-                return node.Value;
-            }
-
-            set {
-                XmlNode node = SelectSingleNode ("/sparkleshare/user/email/text()");
-                node.InnerText = value;
-
-                Save ();
+                this.Save ();
             }
         }
 
@@ -131,6 +144,7 @@ namespace SparkleLib {
             }
         }
 
+
         public void AddFolder (string name, string url, string backend)
         {
             XmlNode node_name = CreateElement ("name");
@@ -150,23 +164,9 @@ namespace SparkleLib {
             XmlNode node_root = SelectSingleNode ("/sparkleshare");
             node_root.AppendChild (node_folder);
 
-            Save ();
+            this.Save ();
         }
 
-        public bool SetFolderOptionalAttribute (string name, string key, string value)
-        {
-            XmlNode folder = this.GetFolder(name);
-            if (folder == null) return false;
-            
-            if (folder[key] != null) {
-                folder[key].InnerText = value;
-            } else {
-                XmlNode new_node = CreateElement(key);
-                new_node.InnerText = value;
-                folder.AppendChild(new_node);
-            }
-            return true;
-        }
 
         public void RemoveFolder (string name)
         {
@@ -175,53 +175,115 @@ namespace SparkleLib {
                     SelectSingleNode ("/sparkleshare").RemoveChild (node_folder);
             }
 
-            Save ();
+            this.Save ();
         }
 
+
+        public bool FolderExists (string name)
+        {
+            XmlNode folder = this.GetFolder (name);
+            return (folder != null);
+        }
+
+
+        public string GetBackendForFolder (string name)
+        {
+            return this.GetFolderValue (name, "backend");
+        }
+
+
+        public string GetUrlForFolder (string name)
+        {
+            return this.GetFolderValue (name, "url");
+        }
+
+
+        public bool SetFolderOptionalAttribute (string folder_name, string key, string value)
+        {
+            XmlNode folder = this.GetFolder (folder_name);
+
+            if (folder == null)
+                return false;
+
+            if (folder [key] != null) {
+                folder [key].InnerText = value;
+
+            } else {
+                XmlNode new_node = CreateElement (key);
+                new_node.InnerText = value;
+                folder.AppendChild (new_node);
+            }
+
+            return true;
+        }
+
+
+        public string GetFolderOptionalAttribute (string folder_name, string key)
+        {
+            XmlNode folder = this.GetFolder (folder_name);
+
+            if (folder != null) {
+                if (folder [key] != null)
+                    return folder [key].InnerText;
+                else
+                    return null;
+
+            } else {
+                return null;
+            }
+        }
+
+
+
+        public List<string> Hosts {
+            get {
+                List<string> hosts = new List<string> ();
+
+                foreach (XmlNode node_folder in SelectNodes ("/sparkleshare/folder")) {
+                    Uri uri = new Uri (node_folder ["url"].InnerText);
+
+                    if (!hosts.Contains (uri.Host))
+                        hosts.Add (uri.Host);
+                }
+
+              return hosts;
+           }
+        }
+
+
+        public List<string> HostsWithUsername {
+            get {
+                List<string> hosts = new List<string> ();
+
+                foreach (XmlNode node_folder in SelectNodes ("/sparkleshare/folder")) {
+                    Uri uri = new Uri (node_folder ["url"].InnerText);
+
+                    if ("git" != uri.UserInfo && !hosts.Contains (uri.UserInfo + "@" + uri.Host))
+                        hosts.Add (uri.UserInfo + "@" + uri.Host);
+                }
+
+              return hosts;
+           }
+        }
+
+
         private XmlNode GetFolder (string name)
         {
-            return SelectSingleNode(String.Format("/sparkleshare/folder[name='{0}']", name));
+            return SelectSingleNode (String.Format("/sparkleshare/folder[name='{0}']", name));
         }
-        
+
+
         private string GetFolderValue (string name, string key)
         {
             XmlNode folder = this.GetFolder(name);
             
-            if ((folder != null) && (folder[key] != null)) {
-                return folder[key].InnerText;
+            if ((folder != null) && (folder [key] != null)) {
+                return folder [key].InnerText;
             }
+
             return null;
         }
 
-        public bool FolderExists (string name)
-        {
-            XmlNode folder = this.GetFolder(name);
-            return folder != null;
-        }
-
-        public string GetBackendForFolder (string name)
-        {
-            return this.GetFolderValue(name, "backend");
-        }
-
-        public string GetUrlForFolder (string name)
-        {
-            return this.GetFolderValue(name, "url");
-        }
-
-        public string GetAnnouncementsForFolder (string name)
-        {
-            return this.GetFolderValue(name, "announcements");
-        }
-
-        public string GetAnnouncementUrlForFolder (string name)
-        {
-            // examples?
-            // tcp://localhost:9999/
-            // xmpp:someuser@somexmppserver?canhavefunnybits
-            // irc://hbons/#somechatroom
-            return this.GetFolderValue(name, "announcements_url");
-        }
 
         public string GetConfigOption (string name)
         {
@@ -250,17 +312,17 @@ namespace SparkleLib {
             }
 
             SparkleHelpers.DebugInfo ("Config", "Updated " + name + ":" + content);
-            Save ();
+            this.Save ();
         }
 
 
-        public void Save ()
+        private void Save ()
         {
-            if (!File.Exists (Path))
-                throw new ConfigFileNotFoundException (Path + " does not exist");
+            if (!File.Exists (FullPath))
+                throw new ConfigFileNotFoundException (FullPath + " does not exist");
 
-            Save (Path);
-            SparkleHelpers.DebugInfo ("Config", "Updated \"" + Path + "\"");
+            this.Save (FullPath);
+            SparkleHelpers.DebugInfo ("Config", "Updated \"" + FullPath + "\"");
         }
     }
 
