@@ -29,25 +29,12 @@ using MonoMac.Growl;
 
 namespace SparkleShare {
 
-    public partial class AppDelegate : NSApplicationDelegate {
-
-        public override void WillBecomeActive (NSNotification notification)
-        {
-            NSApplication.SharedApplication.DockTile.BadgeLabel = null;
-        }
-
-        public override void WillTerminate (NSNotification notification)
-        {
-            SparkleShare.Controller.Quit ();
-        }
-    }
-
-
     public class SparkleUI : AppDelegate {
 
         public static SparkleStatusIcon StatusIcon;
         public static SparkleEventLog EventLog;
-        public static SparkleIntro Intro;
+        public static SparkleSetup Setup;
+        public static SparkleBubbles Bubbles;
         public static SparkleAbout About;
         public static NSFont Font;
 
@@ -69,7 +56,6 @@ namespace SparkleShare {
             // Use translations
             Catalog.Init ("sparkleshare",
                 Path.Combine (NSBundle.MainBundle.ResourcePath, "Translations"));
-            
 
             using (NSAutoreleasePool pool = new NSAutoreleasePool ()) {
 
@@ -79,86 +65,24 @@ namespace SparkleShare {
                 NSApplication.SharedApplication.ApplicationIconImage
                     = NSImage.ImageNamed ("sparkleshare.icns");
 
-                SetFolderIcon ();
-
                 if (!SparkleShare.Controller.BackendIsPresent) {
                     this.alert = new SparkleAlert ();
                     this.alert.RunModal ();
                     return;
                 }
+
+                SetFolderIcon ();
     
                 Font = NSFontManager.SharedFontManager.FontWithFamily
                     ("Lucida Grande", NSFontTraitMask.Condensed, 0, 13);
 
                 StatusIcon = new SparkleStatusIcon ();
-            }
+                Bubbles = new SparkleBubbles ();
 
-            SparkleShare.Controller.NotificationRaised += delegate (string user_name, string user_email,
-                                                                    string message, string repository_path) {
-                InvokeOnMainThread (delegate {
-                    if (EventLog != null)
-                        EventLog.UpdateEvents ();
-
-                    if (SparkleShare.Controller.NotificationsEnabled) {
-                        if (NSApplication.SharedApplication.DockTile.BadgeLabel == null)
-                            NSApplication.SharedApplication.DockTile.BadgeLabel = "1";
-                        else
-                            NSApplication.SharedApplication.DockTile.BadgeLabel =
-                                (int.Parse (NSApplication.SharedApplication.DockTile.BadgeLabel) + 1).ToString ();
-
-                        if (GrowlApplicationBridge.IsGrowlRunning ()) {
-                            SparkleBubble bubble = new SparkleBubble (user_name, message) {
-                                ImagePath = SparkleShare.Controller.GetAvatar (user_email, 36)
-                            };
-
-                            bubble.Show ();
-
-                        } else {
-                          NSApplication.SharedApplication.RequestUserAttention (
-                              NSRequestUserAttentionType.InformationalRequest);
-                        }
-                    }
-                });
-            };
-            
-
-            SparkleShare.Controller.ConflictNotificationRaised += delegate {
-                    string title   = "Ouch! Mid-air collision!";
-                    string subtext = "Don't worry, SparkleShare made a copy of each conflicting file.";
-
-                    new SparkleBubble (title, subtext).Show ();
-            };
-
-
-            SparkleShare.Controller.AvatarFetched += delegate {
-                InvokeOnMainThread (delegate {
-                    if (EventLog != null)
-                        EventLog.UpdateEvents ();
-                });
-            };
-            
-
-            SparkleShare.Controller.OnIdle += delegate {
-                InvokeOnMainThread (delegate {
-                    if (EventLog != null)
-                        EventLog.UpdateEvents ();
-                });
-            };
-
-
-            SparkleShare.Controller.FolderListChanged += delegate {
-                InvokeOnMainThread (delegate {
-                    if (EventLog != null) {
-                        EventLog.UpdateChooser ();
-                        EventLog.UpdateEvents ();
-                    }
-                });
-            };
-
-
-            if (SparkleShare.Controller.FirstRun) {
-                Intro = new SparkleIntro ();
-                Intro.ShowAccountForm ();
+                if (SparkleShare.Controller.FirstRun) {
+                    Setup = new SparkleSetup ();
+                    Setup.Controller.ShowSetupPage ();
+                }
             }
         }
     
@@ -188,4 +112,18 @@ namespace SparkleShare {
             return NSDictionary.FromFile (path);
         }
     }
+
+
+    public partial class AppDelegate : NSApplicationDelegate {
+
+        public override void WillBecomeActive (NSNotification notification)
+        {
+            NSApplication.SharedApplication.DockTile.BadgeLabel = null;
+        }
+
+        public override void WillTerminate (NSNotification notification)
+        {
+            SparkleShare.Controller.Quit ();
+        }
+    }
 }
