@@ -36,7 +36,7 @@ namespace SparkleShare {
 
         public List <SparkleRepoBase> Repositories;
         public string FolderSize;
-        public readonly string SparklePath = SparklePaths.SparklePath;
+        public readonly string SparklePath = SparkleConfig.DefaultConfig.FoldersPath;
 
         public event OnQuitWhileSyncingEventHandler OnQuitWhileSyncing;
         public delegate void OnQuitWhileSyncingEventHandler ();
@@ -75,12 +75,6 @@ namespace SparkleShare {
         public delegate void NotificationRaisedEventHandler (string user_name, string user_email,
                                                              string message, string repository_path);
 
-        public event NewVersionAvailableEventHandler NewVersionAvailable;
-        public delegate void NewVersionAvailableEventHandler (string new_version);
-
-        public event VersionUpToDateEventHandler VersionUpToDate;
-        public delegate void VersionUpToDateEventHandler ();
-
         
         // Short alias for the translations
         public static string _ (string s)
@@ -102,18 +96,13 @@ namespace SparkleShare {
 
             FolderSize = GetFolderSize ();
 
-            // TODO: Legacy. Remove at some later point
-            string old_global_config_file_path = Path.Combine (SparklePaths.SparkleConfigPath, "config");
-            if (File.Exists (old_global_config_file_path))
-                MigrateConfig ();
-
             if (FirstRun)
                 SparkleConfig.DefaultConfig.SetConfigOption ("notifications", bool.TrueString);
             else
                 AddKey ();
 
             // Watch the SparkleShare folder
-            FileSystemWatcher watcher = new FileSystemWatcher (SparklePaths.SparklePath) {
+            FileSystemWatcher watcher = new FileSystemWatcher (SparkleConfig.DefaultConfig.FoldersPath) {
                 IncludeSubdirectories = false,
                 EnableRaisingEvents   = true,
                 Filter                = "*"
@@ -158,41 +147,16 @@ namespace SparkleShare {
 
         public bool FirstRun {
             get {
-                return SparkleConfig.DefaultConfig.UserEmail.Equals ("Unknown");
+                return SparkleConfig.DefaultConfig.User.Email.Equals ("Unknown");
             }
         }
 
 
-         private void MigrateConfig ()
-         {
-            string old_global_config_file_path = Path.Combine (SparklePaths.SparkleConfigPath, "config");
-
-            StreamReader reader = new StreamReader (old_global_config_file_path);
-            string global_config_file = reader.ReadToEnd ();
-            reader.Close ();
-
-            Regex regex = new Regex (@"name.+= (.+)");
-            Match match = regex.Match (global_config_file);
-
-            string user_name = match.Groups [1].Value;
-
-            regex = new Regex (@"email.+= (.+)");
-            match = regex.Match (global_config_file);
-
-            string user_email = match.Groups [1].Value;
-
-            SparkleConfig.DefaultConfig.UserName  = user_name;
-            SparkleConfig.DefaultConfig.UserEmail = user_email;
-
-            File.Delete (old_global_config_file_path);
-        }
-
-
         // Uploads the user's public key to the server
         public bool AcceptInvitation (string server, string folder, string token)
         {
             // The location of the user's public key for SparkleShare
-            string public_key_file_path = SparkleHelpers.CombineMore (SparklePaths.HomePath, ".ssh",
+            string public_key_file_path = SparkleHelpers.CombineMore (SparkleConfig.DefaultConfig.HomePath, ".ssh",
                 "sparkleshare." + UserEmail + ".key.pub");
 
             if (!File.Exists (public_key_file_path))
@@ -230,6 +194,16 @@ namespace SparkleShare {
         }
 
 
+        public List<string> PreviousHosts {
+            get {
+                List<string> hosts = SparkleConfig.DefaultConfig.HostsWithUsername;
+                hosts.AddRange(SparkleConfig.DefaultConfig.Hosts);
+                hosts.Sort ();
+                return hosts;
+            }
+        }
+
+
         public List<string> UnsyncedFolders {
             get {
                 List<string> unsynced_folders = new List<string> ();
@@ -242,14 +216,20 @@ namespace SparkleShare {
                 return unsynced_folders;
             }
         }
-        
+
 
         public List<SparkleChangeSet> GetLog ()
         {
             List<SparkleChangeSet> list = new List<SparkleChangeSet> ();
 
-            foreach (SparkleRepoBase repo in Repositories)
-                list.AddRange (repo.GetChangeSets (50));
+            foreach (SparkleRepoBase repo in Repositories) {
+                List<SparkleChangeSet> change_sets = repo.GetChangeSets (50);
+
+                if (change_sets != null)
+                    list.AddRange (change_sets);
+                else
+                    SparkleHelpers.DebugInfo ("Log", "Could not create log for " + repo.Name);
+            }
 
             list.Sort ((x, y) => (x.Timestamp.CompareTo (y.Timestamp)));
             list.Reverse ();
@@ -266,7 +246,7 @@ namespace SparkleShare {
             if (name == null)
                 return GetLog ();
 
-            string path = Path.Combine (SparklePaths.SparklePath, name);
+            string path = Path.Combine (SparkleConfig.DefaultConfig.FoldersPath, name);
             int log_size = 50;
             
             foreach (SparkleRepoBase repo in Repositories) {
@@ -295,8 +275,8 @@ namespace SparkleShare {
                 return null;
 
             foreach (SparkleChangeSet change_set in change_sets) {
-                if (!emails.Contains (change_set.UserEmail))
-                    emails.Add (change_set.UserEmail);
+                if (!emails.Contains (change_set.User.Email))
+                    emails.Add (change_set.User.Email);
 
                 bool change_set_inserted = false;
                 foreach (ActivityDay stored_activity_day in activity_days) {
@@ -304,7 +284,39 @@ namespace SparkleShare {
                         stored_activity_day.DateTime.Month == change_set.Timestamp.Month &&
                         stored_activity_day.DateTime.Day   == change_set.Timestamp.Day) {
 
-                        stored_activity_day.Add (change_set);
+                        bool squash = false;
+                        foreach (SparkleChangeSet existing_set in stored_activity_day) {
+                            if (change_set.User.Name.Equals (existing_set.User.Name) &&
+                                change_set.User.Email.Equals (existing_set.User.Email) &&
+                                change_set.Folder.Equals (existing_set.Folder)) {
+
+                                existing_set.Added.AddRange (change_set.Added);
+                                existing_set.Edited.AddRange (change_set.Edited);
+                                existing_set.Deleted.AddRange (change_set.Deleted);
+                                existing_set.MovedFrom.AddRange (change_set.MovedFrom);
+                                existing_set.MovedTo.AddRange (change_set.MovedTo);
+                                existing_set.Notes.AddRange (change_set.Notes);
+
+                                existing_set.Added   = existing_set.Added.Distinct ().ToList ();
+                                existing_set.Edited  = existing_set.Edited.Distinct ().ToList ();
+                                existing_set.Deleted = existing_set.Deleted.Distinct ().ToList ();
+
+                                if (DateTime.Compare (existing_set.Timestamp, change_set.Timestamp) < 1) {
+                                    existing_set.FirstTimestamp = existing_set.Timestamp;
+                                    existing_set.Timestamp = change_set.Timestamp;
+                                    existing_set.Revision = change_set.Revision;
+
+                                } else {
+                                    existing_set.FirstTimestamp = change_set.Timestamp;
+                                }
+
+                                squash = true;
+                            }
+                        }
+
+                        if (!squash)
+                            stored_activity_day.Add (change_set);
+
                         change_set_inserted = true;
                         break;
                     }
@@ -318,7 +330,7 @@ namespace SparkleShare {
             }
 
             new Thread (new ThreadStart (delegate {
-                FetchAvatars (emails, 36);
+                FetchAvatars (emails, 48);
             })).Start ();
 
             string event_log_html   = EventLogHTML;
@@ -331,44 +343,44 @@ namespace SparkleShare {
 
                 foreach (SparkleChangeSet change_set in activity_day) {
                     string event_entry = "<dl>";
-                    
-                    if (change_set.IsMerge) {
+
+                    if (change_set.IsMagical) {
                         event_entry += "<dd>Did something magical</dd>";
 
                     } else {
                         if (change_set.Edited.Count > 0) {
                             foreach (string file_path in change_set.Edited) {
-                                string absolute_file_path = SparkleHelpers.CombineMore (SparklePaths.SparklePath,
-                                    change_set.Folder, file_path);
+                                string absolute_file_path = Path.Combine (
+                                    SparkleConfig.DefaultConfig.FoldersPath, change_set.Folder, file_path);
                                 
                                 if (File.Exists (absolute_file_path))
-                                    event_entry += "<dd class='document-edited'><a href='" + absolute_file_path + "'>" + file_path + "</a></dd>";
+                                    event_entry += "<dd class='document edited'><a href='" + absolute_file_path + "'>" + file_path + "</a></dd>";
                                 else
-                                    event_entry += "<dd class='document-edited'>" + file_path + "</dd>";
+                                    event_entry += "<dd class='document edited'>" + file_path + "</dd>";
                             }
                         }
     
                         if (change_set.Added.Count > 0) {
                             foreach (string file_path in change_set.Added) {
-                                string absolute_file_path = SparkleHelpers.CombineMore (SparklePaths.SparklePath,
-                                    change_set.Folder, file_path);
+                                string absolute_file_path = Path.Combine (
+                                    SparkleConfig.DefaultConfig.FoldersPath, change_set.Folder, file_path);
                                 
                                 if (File.Exists (absolute_file_path))
-                                    event_entry += "<dd class='document-added'><a href='" + absolute_file_path + "'>" + file_path + "</a></dd>";
+                                    event_entry += "<dd class='document added'><a href='" + absolute_file_path + "'>" + file_path + "</a></dd>";
                                 else
-                                    event_entry += "<dd class='document-added'>" + file_path + "</dd>";
+                                    event_entry += "<dd class='document added'>" + file_path + "</dd>";
                             }
                         }
     
                         if (change_set.Deleted.Count > 0) {
                             foreach (string file_path in change_set.Deleted) {
-                                string absolute_file_path = SparkleHelpers.CombineMore (SparklePaths.SparklePath,
-                                    change_set.Folder, file_path);
+                                string absolute_file_path = Path.Combine (
+                                    SparkleConfig.DefaultConfig.FoldersPath, change_set.Folder, file_path);
                                 
                                 if (File.Exists (absolute_file_path))
-                                    event_entry += "<dd class='document-deleted'><a href='" + absolute_file_path + "'>" + file_path + "</a></dd>";
+                                    event_entry += "<dd class='document deleted'><a href='" + absolute_file_path + "'>" + file_path + "</a></dd>";
                                 else
-                                    event_entry += "<dd class='document-deleted'>" + file_path + "</dd>";
+                                    event_entry += "<dd class='document deleted'>" + file_path + "</dd>";
                             }
                         }
 
@@ -376,15 +388,15 @@ namespace SparkleShare {
                             int i = 0;
                             foreach (string file_path in change_set.MovedFrom) {
                                 string to_file_path = change_set.MovedTo [i];
-                                string absolute_file_path = SparkleHelpers.CombineMore (SparklePaths.SparklePath,
-                                    change_set.Folder, file_path);
-                                string absolute_to_file_path = SparkleHelpers.CombineMore (SparklePaths.SparklePath,
-                                    change_set.Folder, to_file_path);
+                                string absolute_file_path = Path.Combine (
+                                    SparkleConfig.DefaultConfig.FoldersPath, change_set.Folder, file_path);
+                                string absolute_to_file_path = Path.Combine (
+                                    SparkleConfig.DefaultConfig.FoldersPath, change_set.Folder, file_path);
 
                                 if (File.Exists (absolute_file_path))
-                                    event_entry += "<dd class='document-moved'><a href='" + absolute_file_path + "'>" + file_path + "</a><br/>";
+                                    event_entry += "<dd class='document moved'><a href='" + absolute_file_path + "'>" + file_path + "</a><br/>";
                                 else
-                                    event_entry += "<dd class='document-moved'>" + file_path + "<br/>";
+                                    event_entry += "<dd class='document moved'>" + file_path + "<br/>";
 
                                 if (File.Exists (absolute_to_file_path))
                                     event_entry += "<a href='" + absolute_to_file_path + "'>" + to_file_path + "</a></dd>";
@@ -397,35 +409,48 @@ namespace SparkleShare {
                     }
 
                     string comments = "";
-                    if (change_set.SupportsNotes) {
-                        comments = "<table class=\"comments\">";
+                    comments = "<div class=\"comments\">";
 
-                        if (change_set.Notes != null) {
-                            change_set.Notes.Sort ((x, y) => (x.Timestamp.CompareTo (y.Timestamp)));
-                            
-                            foreach (SparkleNote note in change_set.Notes) {
-                                comments += "<tr>" +
-                                            "  <td class=\"comment-author\">" + note.UserName + "</td>" +
-                                            "  <td class=\"comment-timestamp\">" + note.Timestamp.ToString ("d MMM") + "</td>" +
-                                            "</tr>" +
-                                            "<tr>" +
-                                            "  <td class=\"comment-text\" colspan=\"2\">" + note.Body + "</td>" +
-                                            "</tr>";
-                            }
+                    if (change_set.Notes != null) {
+                        change_set.Notes.Sort ((x, y) => (x.Timestamp.CompareTo (y.Timestamp)));
+
+                        foreach (SparkleNote note in change_set.Notes) {
+
+                            string note_avatar = GetAvatar (note.User.Email, 48);
+                            if (File.Exists (note_avatar))
+                                note_avatar = "file://" + note_avatar;
+                            else
+                                note_avatar = "<!-- $no-buddy-icon-background-image -->";
+
+                            comments += "<div class=\"comment-text\">" +
+                                        "<p class=\"comment-author\"" +
+                                        " style=\"background-image: url('" + note_avatar + "');\">" +
+                                        note.User.Name +  "</p>" +
+                                        note.Body +
+                                        "</div>";
                         }
-
-                        comments += "</table>";
                     }
 
-                    string avatar_email = "";
-                    if (File.Exists (GetAvatar (change_set.UserEmail, 36)))
-                        avatar_email = change_set.UserEmail;
+                    comments += "</div>";
+
+                    string change_set_avatar = GetAvatar (change_set.User.Email, 48);
+                    if (File.Exists (change_set_avatar))
+                        change_set_avatar = "file://" + change_set_avatar;
+                    else
+                        change_set_avatar = "<!-- $no-buddy-icon-background-image -->";
 
                     event_entry   += "</dl>";
+
+                    string timestamp = change_set.Timestamp.ToString ("H:mm");
+
+                    if (!change_set.FirstTimestamp.Equals (new DateTime ()))
+                        timestamp = change_set.FirstTimestamp.ToString ("H:mm") +
+                                    " – " + timestamp;
+
                     event_entries += event_entry_html.Replace ("<!-- $event-entry-content -->", event_entry)
-                        .Replace ("<!-- $event-user-name -->", change_set.UserName)
-                        .Replace ("<!-- $event-avatar-url -->", "file://" + GetAvatar (avatar_email, 36))
-                        .Replace ("<!-- $event-time -->", change_set.Timestamp.ToString ("H:mm"))
+                        .Replace ("<!-- $event-user-name -->", change_set.User.Name)
+                        .Replace ("<!-- $event-avatar-url -->", change_set_avatar)
+                        .Replace ("<!-- $event-time -->", timestamp)
                         .Replace ("<!-- $event-folder -->", change_set.Folder)
                         .Replace ("<!-- $event-revision -->", change_set.Revision)
                         .Replace ("<!-- $event-folder-color -->", AssignColor (change_set.Folder))
@@ -440,32 +465,37 @@ namespace SparkleShare {
                     today.Month == activity_day.DateTime.Month && 
                     today.Year  == activity_day.DateTime.Year) {
 
-                    day_entry = day_entry_html.Replace ("<!-- $day-entry-header -->", "<b>Today</b>");
+                    day_entry = day_entry_html.Replace ("<!-- $day-entry-header -->", "Today");
 
                 } else if (yesterday.Day   == activity_day.DateTime.Day &&
                            yesterday.Month == activity_day.DateTime.Month &&
                            yesterday.Year  == activity_day.DateTime.Year) {
 
-                    day_entry = day_entry_html.Replace ("<!-- $day-entry-header -->", "<b>Yesterday</b>");
+                    day_entry = day_entry_html.Replace ("<!-- $day-entry-header -->", "Yesterday");
 
                 } else {
                     if (activity_day.DateTime.Year != DateTime.Now.Year) {
+
                         // TRANSLATORS: This is the date in the event logs
                         day_entry = day_entry_html.Replace ("<!-- $day-entry-header -->",
-                            "<b>" + activity_day.DateTime.ToString (_("ddd MMM d, yyyy")) + "</b>");
+                            activity_day.DateTime.ToString (_("dddd, MMMM d, yyyy")));
 
                     } else {
+
                         // TRANSLATORS: This is the date in the event logs, without the year
                         day_entry = day_entry_html.Replace ("<!-- $day-entry-header -->",
-                            "<b>" + activity_day.DateTime.ToString (_("ddd MMM d")) + "</b>");
+                            activity_day.DateTime.ToString (_("dddd, MMMM d")));
                     }
                 }
 
                 event_log += day_entry.Replace ("<!-- $day-entry-content -->", event_entries);
             }
 
-            return event_log_html.Replace ("<!-- $event-log-content -->", event_log)
-                .Replace ("<!-- $username -->", UserName);
+            string html =  event_log_html.Replace ("<!-- $event-log-content -->", event_log)
+                .Replace ("<!-- $username -->", UserName)
+                .Replace ("<!-- $user-avatar-url -->", "file://" + GetAvatar (UserEmail, 48));
+
+            return html;
         }
 
 
@@ -489,7 +519,7 @@ namespace SparkleShare {
 
 
         // Fires events for the current syncing state
-        private void UpdateState ()
+        public void UpdateState ()
         {
             foreach (SparkleRepoBase repo in Repositories) {
                 if (repo.Status == SyncStatus.SyncDown ||
@@ -522,7 +552,7 @@ namespace SparkleShare {
         // Adds a repository to the list of repositories
         private void AddRepository (string folder_path)
         {
-            if (folder_path.Equals (SparklePaths.SparkleTmpPath))
+            if (folder_path.Equals (SparkleConfig.DefaultConfig.TmpPath))
                 return;
 
             string folder_name = Path.GetFileName (folder_path);
@@ -533,20 +563,26 @@ namespace SparkleShare {
             
             SparkleRepoBase repo = null;
 
-            if (backend.Equals ("Hg"))
+/*            if (backend.Equals ("Hg"))
                 repo = new SparkleRepoHg (folder_path, new SparkleBackendHg ());
 
             else if (backend.Equals ("Scp"))
                 repo = new SparkleRepoScp (folder_path, new SparkleBackendScp ());
 
-            else
+            else */
                repo = new SparkleRepoGit (folder_path, SparkleBackend.DefaultBackend);
 
-            repo.NewChangeSet += delegate (SparkleChangeSet change_set, string repository_path) {
+            repo.NewChangeSet += delegate (SparkleChangeSet change_set) {
                 string message = FormatMessage (change_set);
 
                 if (NotificationRaised != null)
-                    NotificationRaised (change_set.UserName, change_set.UserEmail, message, repository_path);
+                    NotificationRaised (change_set.User.Name, change_set.User.Email, message, repo.LocalPath);
+            };
+
+            repo.NewNote += delegate (string user_name, string user_email) {
+                if (NotificationRaised != null)
+                    NotificationRaised (user_name, user_email,
+                        "added a note to " + Path.GetFileName (repo.LocalPath), repo.LocalPath);
             };
 
             repo.ConflictResolved += delegate {
@@ -555,6 +591,11 @@ namespace SparkleShare {
             };
 
             repo.SyncStatusChanged += delegate (SyncStatus status) {
+/*                if (status == SyncStatus.SyncUp) {
+                    foreach (string path in repo.UnsyncedFilePaths)
+                        Console.WriteLine (path);
+                }
+*/
                 if (status == SyncStatus.Idle     ||
                     status == SyncStatus.SyncUp   ||
                     status == SyncStatus.SyncDown ||
@@ -598,7 +639,7 @@ namespace SparkleShare {
             Repositories = new List<SparkleRepoBase> ();
 
             foreach (string folder_name in SparkleConfig.DefaultConfig.Folders) {
-                string folder_path = Path.Combine (SparklePaths.SparklePath, folder_name);
+                string folder_path = new SparkleFolder (folder_name).FullPath;
 
                 if (Directory.Exists (folder_path))
                     AddRepository (folder_path);
@@ -646,7 +687,9 @@ namespace SparkleShare {
 
         private string GetFolderSize ()
         {
-            double folder_size = CalculateFolderSize (new DirectoryInfo (SparklePaths.SparklePath));
+            double folder_size = CalculateFolderSize (
+                new DirectoryInfo (SparkleConfig.DefaultConfig.FoldersPath));
+
             return FormatFolderSize (folder_size);
         }
 
@@ -690,7 +733,7 @@ namespace SparkleShare {
             }
 
             return message;
-        }
+        } // TODO: move to bubbles controller
 
 
         // Recursively gets a folder's size in bytes
@@ -753,7 +796,7 @@ namespace SparkleShare {
         // so all activity is done with this key
         public void AddKey ()
         {
-            string keys_path = SparklePaths.SparkleConfigPath;
+            string keys_path = Path.GetDirectoryName (SparkleConfig.DefaultConfig.FullPath);
             string key_file_name = "sparkleshare." + UserEmail + ".key";
 
             Process process = new Process ();
@@ -777,11 +820,11 @@ namespace SparkleShare {
         public string UserName
         {
             get {
-                return SparkleConfig.DefaultConfig.UserName;
+                return SparkleConfig.DefaultConfig.User.Name;
             }
 
             set {
-                SparkleConfig.DefaultConfig.UserName = value;
+                SparkleConfig.DefaultConfig.User = new SparkleUser (value, UserEmail);
             }
         }
 
@@ -790,11 +833,11 @@ namespace SparkleShare {
         public string UserEmail
         {
             get {
-                return SparkleConfig.DefaultConfig.UserEmail;
+                return SparkleConfig.DefaultConfig.User.Email;
             }
                     
             set {
-                SparkleConfig.DefaultConfig.UserEmail = value;
+                SparkleConfig.DefaultConfig.User = new SparkleUser (UserName, value);
             }
         }
         
@@ -802,7 +845,7 @@ namespace SparkleShare {
         // Generates and installs an RSA keypair to identify this system
         public void GenerateKeyPair ()
         {
-            string keys_path     = SparklePaths.SparkleConfigPath;
+            string keys_path     = Path.GetDirectoryName (SparkleConfig.DefaultConfig.FullPath);
             string key_file_name = "sparkleshare." + UserEmail + ".key";
             string key_file_path = Path.Combine (keys_path, key_file_name);
 
@@ -851,8 +894,9 @@ namespace SparkleShare {
         {
             List<string> old_avatars = new List<string> ();
             bool avatar_fetched      = false;
-            string avatar_path       = SparkleHelpers.CombineMore (
-                SparklePaths.SparkleLocalIconPath, size + "x" + size, "status");
+            string avatar_path       = Path.Combine (
+                Path.GetDirectoryName (SparkleConfig.DefaultConfig.FullPath), "icons",
+                size + "x" + size, "status");
 
             if (!Directory.Exists (avatar_path)) {
                 Directory.CreateDirectory (avatar_path);
@@ -888,8 +932,12 @@ namespace SparkleShare {
                         SparkleHelpers.DebugInfo ("Controller", "Fetched gravatar for " + email);
                     }
 
-                  } catch (WebException) {
+                  } catch (WebException e) {
                         SparkleHelpers.DebugInfo ("Controller", "Failed fetching gravatar for " + email);
+
+                        // Stop downloading further avatars if we have no internet access
+                        if (e.Status == WebExceptionStatus.Timeout)
+                            break;
                   }
                }
             }
@@ -907,7 +955,8 @@ namespace SparkleShare {
         public string GetAvatar (string email, int size)
         {
             string avatar_file_path = SparkleHelpers.CombineMore (
-                SparklePaths.SparkleLocalIconPath, size + "x" + size, "status", "avatar-" + email);
+                Path.GetDirectoryName (SparkleConfig.DefaultConfig.FullPath), "icons",
+                size + "x" + size, "status", "avatar-" + email);
 
             return avatar_file_path;
         }
@@ -918,17 +967,18 @@ namespace SparkleShare {
             server = server.Trim ();
             remote_folder = remote_folder.Trim ();
 
-            if (!Directory.Exists (SparklePaths.SparkleTmpPath))
-                Directory.CreateDirectory (SparklePaths.SparkleTmpPath);
+            string tmp_path = SparkleConfig.DefaultConfig.TmpPath;
+            if (!Directory.Exists (tmp_path))
+                Directory.CreateDirectory (tmp_path);
 
             // Strip the '.git' from the name
             string canonical_name = Path.GetFileNameWithoutExtension (remote_folder);
-            string tmp_folder     = Path.Combine (SparklePaths.SparkleTmpPath, canonical_name);
+            string tmp_folder     = Path.Combine (tmp_path, canonical_name);
 
             SparkleFetcherBase fetcher = null;
             string backend = null;
 
-            if (remote_folder.EndsWith (".hg")) {
+/*            if (remote_folder.EndsWith (".hg")) {
                 remote_folder = remote_folder.Substring (0, (remote_folder.Length - 3));
                 fetcher       = new SparkleFetcherHg (server, remote_folder, tmp_folder);
                 backend       = "Hg";
@@ -938,12 +988,13 @@ namespace SparkleShare {
                 fetcher = new SparkleFetcherScp (server, remote_folder, tmp_folder);
                 backend = "Scp";
 
-            } else {
+            } else {*/
                 fetcher = new SparkleFetcherGit (server, remote_folder, tmp_folder);
                 backend = "Git";
-            }
+            //}
 
-            bool target_folder_exists = Directory.Exists (Path.Combine (SparklePaths.SparklePath, canonical_name));
+            bool target_folder_exists = Directory.Exists (
+                Path.Combine (SparkleConfig.DefaultConfig.FoldersPath, canonical_name));
 
             // Add a numbered suffix to the nameif a folder with the same name
             // already exists. Example: "Folder (2)"
@@ -951,7 +1002,7 @@ namespace SparkleShare {
             while (target_folder_exists) {
                 i++;
                 target_folder_exists = Directory.Exists (
-                    Path.Combine (SparklePaths.SparklePath, canonical_name + " (" + i + ")"));
+                    Path.Combine (SparkleConfig.DefaultConfig.FoldersPath, canonical_name + " (" + i + ")"));
             }
 
             string target_folder_name = canonical_name;
@@ -962,7 +1013,8 @@ namespace SparkleShare {
 
                 // Needed to do the moving
                 SparkleHelpers.ClearAttributes (tmp_folder);
-                string target_folder_path = Path.Combine (SparklePaths.SparklePath, target_folder_name);
+                string target_folder_path = Path.Combine (
+                    SparkleConfig.DefaultConfig.FoldersPath, target_folder_name);
 
                 try {
                     Directory.Move (tmp_folder, target_folder_path);
@@ -986,20 +1038,19 @@ namespace SparkleShare {
 
                 fetcher.Dispose ();
 
-                if (Directory.Exists (SparklePaths.SparkleTmpPath))
-                    Directory.Delete (SparklePaths.SparkleTmpPath, true);
+                if (Directory.Exists (tmp_path))
+                    Directory.Delete (tmp_path, true);
             };
 
 
             fetcher.Failed += delegate {
-
                 if (FolderFetchError != null)
                     FolderFetchError ();
 
                 fetcher.Dispose ();
 
-                if (Directory.Exists (SparklePaths.SparkleTmpPath))
-                    Directory.Delete (SparklePaths.SparkleTmpPath, true);
+                if (Directory.Exists (tmp_path))
+                    Directory.Delete (tmp_path, true);
             };
 
 
@@ -1054,15 +1105,13 @@ namespace SparkleShare {
         }
 
 
-        public string Version {
-            get {
-                return SparkleBackend.Version;
-            }
-        }
 
 
         public void AddNoteToFolder (string folder_name, string revision, string note)
         {
+            folder_name = folder_name.Replace ("%20", " ");
+            note        = note.Replace ("%20", " ");
+
             foreach (SparkleRepoBase repo in Repositories) {
                 if (repo.Name.Equals (folder_name))
                     repo.AddNote (revision, note);
@@ -1070,29 +1119,6 @@ namespace SparkleShare {
         }
 
 
-        public void CheckForNewVersion ()
-        {
-            WebClient web_client = new WebClient ();
-            Uri uri = new Uri ("http://www.sparkleshare.org/version");
-
-            web_client.DownloadStringCompleted += delegate (object o, DownloadStringCompletedEventArgs args) {
-                if (args.Error != null)
-                    return;
-
-                string new_version = args.Result.Trim ();
-
-                if (Version.Equals (new_version)) {
-                    if (VersionUpToDate != null)
-                        VersionUpToDate ();
-
-                } else {
-                    if (NewVersionAvailable != null)
-                        NewVersionAvailable (new_version);
-                }
-            };
-
-            web_client.DownloadStringAsync (uri);
-        }
 
 
         private string [] tango_palette = new string [] {"#eaab00", "#e37222",
